pub enum CustomPaneDock {
Bottom,
Right,
}Expand description
Dock position for the custom pane.
Variants
Bottom
Dock the custom pane below the file list (default).
Right
Dock the custom pane on the right side, similar to IGFD sidePane.