pub struct WindowHostConfig {
pub title: String,
pub initial_size: [f32; 2],
pub size_condition: Condition,
pub min_size: Option<[f32; 2]>,
pub max_size: Option<[f32; 2]>,
}Expand description
Configuration for hosting the file browser in an ImGui window.
Fields
title: StringWindow title
initial_size: [f32; 2]Initial window size (used with size_condition)
size_condition: ConditionCondition used when setting the window size
min_size: Option<[f32; 2]>Optional minimum size constraint.
max_size: Option<[f32; 2]>Optional maximum size constraint.
Implementations
Sourceimpl WindowHostConfig
impl WindowHostConfig
Sourcepub fn for_mode(mode: DialogMode) -> Self
pub fn for_mode(mode: DialogMode) -> Self
Default window host configuration for the given dialog mode.