CustomPane

Trait CustomPane 

pub trait CustomPane {
    // Required method
    fn draw(&mut self, ui: &Ui, ctx: CustomPaneCtx<'_>) -> ConfirmGate;
}
IGFD-style custom pane that can draw extra UI and optionally block confirmation.

The pane is rendered inside the file dialog (typically below the file list). It returns a ConfirmGate each frame which is used to enable/disable the confirm action (button, Enter key, double-click confirm, etc).

Required Methods

fn draw(&mut self, ui: &Ui, ctx: CustomPaneCtx<'_>) -> ConfirmGate

Draw the pane contents and return the current confirm gate.

Implementors